
# Manage Alooma

Manage Alooma provides code used to programmatically manage the Alooma ETL tool via its API and generic transformation code for manipulating data.

# Full Docs

* Docs: http://managealooma.readthedocs.org/ 
* Source: https://github.com/hoverinc/managealooma
* Download: http://pypi.python.org/pypi/managealooma

# About Alooma

Alooma is an ETL tool for building out datawarehouses. Alooma does the basic tasks of connecting to sources for you such
 as replicating a database, receiving a webhook or  connecting to a cloud app API. Alooma also inserts your data to a
 datawarehouse such as Snowflake, Redshift, or Bigquery.  In between those steps Alooma allows you to transform your
data any way you want using real Python code.  This package contains may functions to make programmatic management of
Alooma easy!